@@ -61,3 +61,27 @@ def load_smiles(path: str,
     groups = [] if groups_column not in column_names else list(loaded_data_df[groups_column])
 
     return smiles, values, epoch, groups
+
+
+def save_df(path, chemdata_list: list):
+    for idx, chemdata in enumerate(chemdata_list):
+        # update path
+        first_part_path = path.split(".", 1)[0]
+        updated_path = f'{first_part_path}_{idx:04}.csv'
+
+        # generate df
+        df = pd.DataFrame({"UMAP_1": chemdata.get_embedding().np_array[:, 0],
+                           "UMAP_2": chemdata.get_embedding().np_array[:, 1],
+                           "SMILES": list(chemdata.get_smiles()),
+                           })
+
+        if len(chemdata.get_epochs()) >= 1:
+            df["Epochs"] = chemdata.get_epochs()
+
+        if len(chemdata.get_groups()) >= 1:
+            df["Groups"] = chemdata.get_groups()
+
+        df_concat = pd.concat([df, chemdata.get_values()], axis=1)
+
+        # convert to csv
+        df_concat.to_csv(updated_path, index=None)
